@@ -41,7 +41,6 @@
 #include <QImage>
 #include <QStackedWidget>
 #include <QStandardPaths>
-#include <QLocale>
 #include "element.h"
 #include "orbitswidget.h"
 #include "detailedgraphicaloverview.h"
@@ -113,11 +112,11 @@ void DetailedInfoDlg::setElement(int el)
     reloadContent();
 
   /* enableButton(User1, true);
-   enableButton(User2, true);
+   user2Button->setEnabled(true);
     if (m_elementNumber == 1) {
-        enableButton(User2, false);
+        user2Button->setEnabled(false);
     } else if (m_elementNumber == KalziumDataObject::instance()->numberOfElements()) {
-        enableButton(User1, false);
+        user1Button->setEnabled(false);
     }*/
 }
 
@@ -319,7 +318,7 @@ QString DetailedInfoDlg::getHtml(DATATYPE type)
         html.append ("<tr><td>");
         html.append ("<a href=\"http://");        // http://
         html.append ("www.webelements.com/");
-        if (QLocale().uiLanguages().first().startsWith("en")) {
+        if (QLocale().uiLanguages().first().startsWith(QLatin1String("en"))) {
             html.append (m_element->dataAsString(ChemicalDataObject::name).toLower()); // hydrogen
         }
         html.append ("\" target=\"_blank\" >");
@@ -449,7 +448,7 @@ QString DetailedInfoDlg::isotopeTable() const
 
 void DetailedInfoDlg::createContent()
 {
-    KPageWidgetItem *item = 0;
+    KPageWidgetItem *item = nullptr;
 
    // Removed the overview Tab, because its an Dockwidget and dosn't show much information.
     // overview tab
@@ -591,7 +590,7 @@ void DetailedInfoDlg::slotLinkClicked(const QUrl &url)
     if (url.isEmpty() || !url.isValid()) {
         return;
     }
-    KRun::runUrl(url, QStringLiteral("text/html"), nullptr);
+    KRun::runUrl(url, QStringLiteral("text/html"), this, KRun::RunFlags(), QString(), QByteArray());
 }
 
 void DetailedInfoDlg::slotHelp()
@@ -623,7 +622,7 @@ void DetailedInfoDlg::slotHelp()
         break;
     }
 #endif
-   KHelpClient::invokeHelp("infodialog_spectrum", QLatin1String("kalzium"));
+   KHelpClient::invokeHelp("info-dlg.html#infodialog_spectrum", QLatin1String("kalzium"));
 }
 
 void DetailedInfoDlg::showNextElement()
