@@ -14,7 +14,7 @@
 #ifndef ELEMENTDATAVIEWER_H
 #define ELEMENTDATAVIEWER_H
 
-#include <kdialog.h>
+#include <QDialog>
 #include "ui_plotsetupwidget.h"
 #include "kalziumdataobject.h"
 #include "kalziumutils.h"
@@ -84,12 +84,12 @@ private:
  * where you can setup the plot
  * @author Carsten Niehaus
  */
-class ElementDataViewer : public KDialog
+class ElementDataViewer : public QDialog
 {
     Q_OBJECT
 
 public:
-    ElementDataViewer(QWidget *parent = 0);
+    ElementDataViewer(QWidget *parent = nullptr);
 
     ~ElementDataViewer();
 
@@ -105,7 +105,7 @@ public:
 
 
 protected:
-    virtual void keyPressEvent(QKeyEvent *e);
+    void keyPressEvent(QKeyEvent *e) override;
 
 private:
     Ui::PlotSetupWidget ui;
