@@ -23,8 +23,6 @@
 #include <QClipboard>
 #include <QDebug>
 
-#include <klocale.h>
-
 #include <LineEditUrlDropEventFilter>
 
 #include "ui_equationview.h"
@@ -50,7 +48,7 @@ void EQChemDialog::compute()
     equation.append(' ');
     equation.prepend(' ');
 
-    char * result = solve_equation(equation.toLatin1());
+    char * result = solve_equation(equation.toLatin1().constData());
 
     QString answer = QString(result);
 
